<script setup lang="ts">
import { ref, onMounted, onUnmounted } from 'vue';
import * as echarts from 'echarts';
import { createDataReceiver } from '../utils/dataFetcher';

const chartContainer = ref<HTMLElement | null>(null);
let chart: echarts.ECharts | null = null;

// 存储当前的力数据
const currentData = ref<number[]>([0, 0, 0, 0, 0, 0]);

// 初始化图表
function initChart() {
  if (!chartContainer.value) return;
  
  chart = echarts.init(chartContainer.value);
  
  const option = {
    title: {
      text: '六维力实时数据',
      left: 'center'
    },
    tooltip: {
      formatter: '{b}: {c}'
    },
    grid: {
      top: 50,
      bottom: 50,
      left: '5%',
      right: '5%',
      containLabel: true
    },
    series: [
      {
        name: 'Fx',
        type: 'gauge',
        min: 1000,
        max: 4000,
        splitNumber: 10,
        radius: '30%',
        center: ['16.7%', '30%'],
        axisLabel: {
          formatter: function(value: number) {
            // return value + 'N';
            return value;
          }
        },
        detail: { 
          formatter: function(value: number) {
            return value.toFixed(2) + 'N';
          },
          offsetCenter: [0, '90%'],
          fontSize: 18
        },
        data: [{ value: currentData.value[0], name: 'Fx' }]
      },
      {
        name: 'Fy',
        type: 'gauge',
        min: 1000,
        max: 4000,
        splitNumber: 10,
        radius: '30%',
        center: ['50%', '30%'],
        axisLabel: {
          formatter: function(value: number) {
            // return value + 'N';
            return value;
          }
        },
        detail: { 
          formatter: function(value: number) {
            return value.toFixed(2) + 'N';
          },
          offsetCenter: [0, '90%'],
          fontSize: 18
        },
        data: [{ value: currentData.value[1], name: 'Fy' }]
      },
      {
        name: 'Fz',
        type: 'gauge',
        min: 1000,
        max: 4000,
        splitNumber: 10,
        radius: '30%',
        center: ['83.3%', '30%'],
        axisLabel: {
          formatter: function(value: number) {
            // return value + 'N';
            return value;
          }
        },
        detail: { 
          formatter: function(value: number) {
            return value.toFixed(2) + 'N';
          },
          offsetCenter: [0, '90%'],
          fontSize: 18
        },
        data: [{ value: currentData.value[2], name: 'Fz' }]
      },
      {
        name: 'Mx',
        type: 'gauge',
        min: 1000,
        max: 4000,
        splitNumber: 10,
        radius: '30%',
        center: ['16.7%', '75%'],
        axisLabel: {
          formatter: function(value: number) {
            // return value + 'Nm';
            return value;
          }
        },
        detail: { 
          formatter: function(value: number) {
            return value.toFixed(2) + 'Nm';
          },
          offsetCenter: [0, '90%'],
          fontSize: 18
        },
        data: [{ value: currentData.value[3], name: 'Mx' }]
      },
      {
        name: 'My',
        type: 'gauge',
        min: 1000,
        max: 4000,
        splitNumber: 10,
        radius: '30%',
        center: ['50%', '75%'],
        axisLabel: {
          formatter: function(value: number) {
            // return value + 'Nm';
            return value;
          }
        },
        detail: { 
          formatter: function(value: number) {
            return value.toFixed(2) + 'Nm';
          },
          offsetCenter: [0, '90%'],
          fontSize: 18
        },
        data: [{ value: currentData.value[4], name: 'My' }]
      },
      {
        name: 'Mz',
        type: 'gauge',
        min: 1000,
        max: 4000,
        splitNumber: 10,
        radius: '30%',
        center: ['83.3%', '75%'],
        axisLabel: {
          formatter: function(value: number) {
            // return value + 'Nm';
            return value;
          }
        },
        detail: { 
          formatter: function(value: number) {
            return value.toFixed(2) + 'Nm';
          },
          offsetCenter: [0, '90%'],
          fontSize: 18
        },
        data: [{ value: currentData.value[5], name: 'Mz' }]
      }
    ]
  };
  
  chart.setOption(option);
}

// 更新图表数据
function updateChart(forceData: number[]) {
  if (!chart) return;
  
  currentData.value = forceData;
  
  chart.setOption({
    series: [
      {
        data: [{ value: forceData[0], name: 'Fx' }]
      },
      {
        data: [{ value: forceData[1], name: 'Fy' }]
      },
      {
        data: [{ value: forceData[2], name: 'Fz' }]
      },
      {
        data: [{ value: forceData[3], name: 'Mx' }]
      },
      {
        data: [{ value: forceData[4], name: 'My' }]
      },
      {
        data: [{ value: forceData[5], name: 'Mz' }]
      }
    ]
  });
}



let dataInterval: number | null = null;

onMounted(() => {
  initChart();
  
  const receiveData = createDataReceiver((forceData) => {
    updateChart(forceData);
  });
  
  // 每200ms获取一次数据
  dataInterval = window.setInterval(receiveData, 200);
  
  // 监听窗口大小变化，调整图表大小
  window.addEventListener('resize', handleResize);
});

onUnmounted(() => {
  if (dataInterval !== null) {
    clearInterval(dataInterval);
  }
  
  if (chart) {
    chart.dispose();
    chart = null;
  }
  
  window.removeEventListener('resize', handleResize);
});

function handleResize() {
  if (chart) {
    chart.resize();
  }
}
</script>

<template>
  <div class="gauge-container">
    <div ref="chartContainer" class="chart"></div>
  </div>
</template>

<style scoped>
.gauge-container {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
}

.chart {
  width: 100%;
  height: 700px;
  padding: 10px;
}
</style>